function Setup_FSx( fsxID)
%% Setup_FSx is used to handle a R&S spectrum analyzer
% for the radar closed loop application
% The function needs the Hostname of the spectrum analyzer as input
% parameter. FSx will be setup to analog Phasedemodulation.
% 
% exemplary usage:
% recordData('rsfsq26100026', 'RadarRecord.csv');

global settings;

h = waitbar(0.1, ['Setting up ' fsxID]);                  % open waitbar

%% instrument setup
[~, deviceObj] = rs_connect('tcpip', fsxID);
rs_send_command(deviceObj, 'PRES');                         % preset baseband
rs_send_query(deviceObj, '*OPC?');
waitbar(0.5, h);

rs_send_command(deviceObj, 'SYST:DISP:UPD ON');               % Turn the display ON

rs_send_command(deviceObj, ['FREQ:CENT ' settings.frequency]);        % set center frequency
rs_send_command(deviceObj, ['DISP:TRACE:Y:RLEVEL ' settings.level]);  % set reference level
rs_send_command(deviceObj, 'FREQ:SPAN 0Hz');                % zero span
rs_send_command(deviceObj, 'ROSC:SOUR EXT');                % external reference
rs_send_query(deviceObj, '*OPC?');
waitbar(0.8, h);

rs_send_command(deviceObj, 'ADEM ON');                      % enter analog demodulation mode
rs_send_command(deviceObj, 'CALC:FEED ''XTIM:PM''');        % PM mode
rs_send_command(deviceObj, 'ADEM:MTIMe 52us');             % measurement time is 60us 
rs_send_command(deviceObj, 'ADEMod1:AF:COUPling DC');       % AF coupling DC 
% number of data points in measurement :
rs_send_command(deviceObj, ['SWEEP:POINTS ' num2str(settings.numPoints)]);  

rs_send_command(deviceObj, 'INIT:CONT ON');                 % sweep mode to collect samples
rs_send_query(deviceObj, '*OPC?');

rs_send_command(deviceObj, 'INIT:CONT OFF');                % single sweep mode

rs_send_command(deviceObj, 'TRIG:SOUR EXT');                % trigger Setup
rs_send_query(deviceObj, '*OPC?');

clear  deviceObj;

close(h);                                                   % close waitbar

